@@ -8,6 +8,7 @@ from .base_client import \
 from .environment import ElevenLabsEnvironment
 from .realtime_tts import RealtimeTextToSpeechClient
 from .webhooks_custom import WebhooksClient, AsyncWebhooksClient
+from .music_custom import MusicClient, AsyncMusicClient
 
 
 # this is used as the default value for optional parameters
@@ -31,7 +32,7 @@ class ElevenLabs(BaseElevenLabs):
 
         - api_key: typing.Optional[str].
 
-        - timeout: typing.Optional[float]. The timeout to be used, in seconds, for requests by default the timeout is 60 seconds.
+        - timeout: typing.Optional[float]. The timeout to be used, in seconds, for requests by default the timeout is 240 seconds.
 
         - httpx_client: typing.Optional[httpx.Client]. The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.
     ---
@@ -47,20 +48,19 @@ class ElevenLabs(BaseElevenLabs):
         base_url: typing.Optional[str] = None,
         environment: ElevenLabsEnvironment = ElevenLabsEnvironment.PRODUCTION,
         api_key: typing.Optional[str] = os.getenv("ELEVENLABS_API_KEY"),
-        timeout: typing.Optional[float] = 60,
+        timeout: typing.Optional[float] = 240,
         httpx_client: typing.Optional[httpx.Client] = None
     ):
         super().__init__(
-            environment=ElevenLabsEnvironment(
-                base=f"https://{get_base_url_host(base_url)}",
-                wss=f"wss://{get_base_url_host(base_url)}",
-            ) if base_url else environment,
+            base_url=base_url,
+            environment=environment,
             api_key=api_key,
             timeout=timeout,
             httpx_client=httpx_client
         )
-        self.text_to_speech = RealtimeTextToSpeechClient(client_wrapper=self._client_wrapper)
-        self.webhooks = WebhooksClient(client_wrapper=self._client_wrapper)
+        self._text_to_speech = RealtimeTextToSpeechClient(client_wrapper=self._client_wrapper)
+        self._webhooks = WebhooksClient(client_wrapper=self._client_wrapper)
+        self._music = MusicClient(client_wrapper=self._client_wrapper)
 
 
 class AsyncElevenLabs(AsyncBaseElevenLabs):
@@ -76,7 +76,7 @@ class AsyncElevenLabs(AsyncBaseElevenLabs):
 
         - api_key: typing.Optional[str].
 
-        - timeout: typing.Optional[float]. The timeout to be used, in seconds, for requests by default the timeout is 60 seconds.
+        - timeout: typing.Optional[float]. The timeout to be used, in seconds, for requests by default the timeout is 240 seconds.
 
         - httpx_client: typing.Optional[httpx.AsyncClient]. The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.
     ---
@@ -93,18 +93,15 @@ class AsyncElevenLabs(AsyncBaseElevenLabs):
         base_url: typing.Optional[str] = None,
         environment: ElevenLabsEnvironment = ElevenLabsEnvironment.PRODUCTION,
         api_key: typing.Optional[str] = os.getenv("ELEVENLABS_API_KEY"),
-        timeout: typing.Optional[float] = 60,
+        timeout: typing.Optional[float] = 240,
         httpx_client: typing.Optional[httpx.AsyncClient] = None
     ):
         super().__init__(
-            environment=base_url
-            and ElevenLabsEnvironment(
-                base=f"https://{get_base_url_host(base_url)}",
-                wss=f"wss://{get_base_url_host(base_url)}",
-            )
-            or environment,
+            base_url=base_url,
+            environment=environment,
             api_key=api_key,
             timeout=timeout,
             httpx_client=httpx_client
         )
-        self.webhooks = AsyncWebhooksClient(client_wrapper=self._client_wrapper)
+        self._webhooks = AsyncWebhooksClient(client_wrapper=self._client_wrapper)
+        self._music = AsyncMusicClient(client_wrapper=self._client_wrapper)
